@@ -1,4 +1,3 @@
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import,unused-argument,super-init-not-called
 """
 Main interface for amplify service client
 
@@ -94,7 +93,7 @@ class Exceptions:
 
 class AmplifyClient:
     """
-    [Amplify.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client)
+    [Amplify.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client)
     """
 
     meta: ClientMeta
@@ -102,7 +101,7 @@ class AmplifyClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.can_paginate)
         """
 
     def create_app(
@@ -122,12 +121,13 @@ class AmplifyClient:
         customRules: List["CustomRuleTypeDef"] = None,
         tags: Dict[str, str] = None,
         buildSpec: str = None,
+        customHeaders: str = None,
         enableAutoBranchCreation: bool = None,
         autoBranchCreationPatterns: List[str] = None,
         autoBranchCreationConfig: "AutoBranchCreationConfigTypeDef" = None,
     ) -> CreateAppResultTypeDef:
         """
-        [Client.create_app documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.create_app)
+        [Client.create_app documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.create_app)
         """
 
     def create_backend_environment(
@@ -138,7 +138,7 @@ class AmplifyClient:
         deploymentArtifacts: str = None,
     ) -> CreateBackendEnvironmentResultTypeDef:
         """
-        [Client.create_backend_environment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.create_backend_environment)
+        [Client.create_backend_environment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.create_backend_environment)
         """
 
     def create_branch(
@@ -163,14 +163,14 @@ class AmplifyClient:
         backendEnvironmentArn: str = None,
     ) -> CreateBranchResultTypeDef:
         """
-        [Client.create_branch documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.create_branch)
+        [Client.create_branch documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.create_branch)
         """
 
     def create_deployment(
         self, appId: str, branchName: str, fileMap: Dict[str, str] = None
     ) -> CreateDeploymentResultTypeDef:
         """
-        [Client.create_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.create_deployment)
+        [Client.create_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.create_deployment)
         """
 
     def create_domain_association(
@@ -183,55 +183,55 @@ class AmplifyClient:
         autoSubDomainIAMRole: str = None,
     ) -> CreateDomainAssociationResultTypeDef:
         """
-        [Client.create_domain_association documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.create_domain_association)
+        [Client.create_domain_association documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.create_domain_association)
         """
 
     def create_webhook(
         self, appId: str, branchName: str, description: str = None
     ) -> CreateWebhookResultTypeDef:
         """
-        [Client.create_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.create_webhook)
+        [Client.create_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.create_webhook)
         """
 
     def delete_app(self, appId: str) -> DeleteAppResultTypeDef:
         """
-        [Client.delete_app documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.delete_app)
+        [Client.delete_app documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.delete_app)
         """
 
     def delete_backend_environment(
         self, appId: str, environmentName: str
     ) -> DeleteBackendEnvironmentResultTypeDef:
         """
-        [Client.delete_backend_environment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.delete_backend_environment)
+        [Client.delete_backend_environment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.delete_backend_environment)
         """
 
     def delete_branch(self, appId: str, branchName: str) -> DeleteBranchResultTypeDef:
         """
-        [Client.delete_branch documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.delete_branch)
+        [Client.delete_branch documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.delete_branch)
         """
 
     def delete_domain_association(
         self, appId: str, domainName: str
     ) -> DeleteDomainAssociationResultTypeDef:
         """
-        [Client.delete_domain_association documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.delete_domain_association)
+        [Client.delete_domain_association documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.delete_domain_association)
         """
 
     def delete_job(self, appId: str, branchName: str, jobId: str) -> DeleteJobResultTypeDef:
         """
-        [Client.delete_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.delete_job)
+        [Client.delete_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.delete_job)
         """
 
     def delete_webhook(self, webhookId: str) -> DeleteWebhookResultTypeDef:
         """
-        [Client.delete_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.delete_webhook)
+        [Client.delete_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.delete_webhook)
         """
 
     def generate_access_logs(
         self, domainName: str, appId: str, startTime: datetime = None, endTime: datetime = None
     ) -> GenerateAccessLogsResultTypeDef:
         """
-        [Client.generate_access_logs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.generate_access_logs)
+        [Client.generate_access_logs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.generate_access_logs)
         """
 
     def generate_presigned_url(
@@ -242,105 +242,105 @@ class AmplifyClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.generate_presigned_url)
         """
 
     def get_app(self, appId: str) -> GetAppResultTypeDef:
         """
-        [Client.get_app documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.get_app)
+        [Client.get_app documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.get_app)
         """
 
     def get_artifact_url(self, artifactId: str) -> GetArtifactUrlResultTypeDef:
         """
-        [Client.get_artifact_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.get_artifact_url)
+        [Client.get_artifact_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.get_artifact_url)
         """
 
     def get_backend_environment(
         self, appId: str, environmentName: str
     ) -> GetBackendEnvironmentResultTypeDef:
         """
-        [Client.get_backend_environment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.get_backend_environment)
+        [Client.get_backend_environment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.get_backend_environment)
         """
 
     def get_branch(self, appId: str, branchName: str) -> GetBranchResultTypeDef:
         """
-        [Client.get_branch documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.get_branch)
+        [Client.get_branch documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.get_branch)
         """
 
     def get_domain_association(
         self, appId: str, domainName: str
     ) -> GetDomainAssociationResultTypeDef:
         """
-        [Client.get_domain_association documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.get_domain_association)
+        [Client.get_domain_association documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.get_domain_association)
         """
 
     def get_job(self, appId: str, branchName: str, jobId: str) -> GetJobResultTypeDef:
         """
-        [Client.get_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.get_job)
+        [Client.get_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.get_job)
         """
 
     def get_webhook(self, webhookId: str) -> GetWebhookResultTypeDef:
         """
-        [Client.get_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.get_webhook)
+        [Client.get_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.get_webhook)
         """
 
     def list_apps(self, nextToken: str = None, maxResults: int = None) -> ListAppsResultTypeDef:
         """
-        [Client.list_apps documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.list_apps)
+        [Client.list_apps documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.list_apps)
         """
 
     def list_artifacts(
         self, appId: str, branchName: str, jobId: str, nextToken: str = None, maxResults: int = None
     ) -> ListArtifactsResultTypeDef:
         """
-        [Client.list_artifacts documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.list_artifacts)
+        [Client.list_artifacts documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.list_artifacts)
         """
 
     def list_backend_environments(
         self, appId: str, environmentName: str = None, nextToken: str = None, maxResults: int = None
     ) -> ListBackendEnvironmentsResultTypeDef:
         """
-        [Client.list_backend_environments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.list_backend_environments)
+        [Client.list_backend_environments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.list_backend_environments)
         """
 
     def list_branches(
         self, appId: str, nextToken: str = None, maxResults: int = None
     ) -> ListBranchesResultTypeDef:
         """
-        [Client.list_branches documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.list_branches)
+        [Client.list_branches documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.list_branches)
         """
 
     def list_domain_associations(
         self, appId: str, nextToken: str = None, maxResults: int = None
     ) -> ListDomainAssociationsResultTypeDef:
         """
-        [Client.list_domain_associations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.list_domain_associations)
+        [Client.list_domain_associations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.list_domain_associations)
         """
 
     def list_jobs(
         self, appId: str, branchName: str, nextToken: str = None, maxResults: int = None
     ) -> ListJobsResultTypeDef:
         """
-        [Client.list_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.list_jobs)
+        [Client.list_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.list_jobs)
         """
 
     def list_tags_for_resource(self, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.list_tags_for_resource)
         """
 
     def list_webhooks(
         self, appId: str, nextToken: str = None, maxResults: int = None
     ) -> ListWebhooksResultTypeDef:
         """
-        [Client.list_webhooks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.list_webhooks)
+        [Client.list_webhooks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.list_webhooks)
         """
 
     def start_deployment(
         self, appId: str, branchName: str, jobId: str = None, sourceUrl: str = None
     ) -> StartDeploymentResultTypeDef:
         """
-        [Client.start_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.start_deployment)
+        [Client.start_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.start_deployment)
         """
 
     def start_job(
@@ -355,22 +355,22 @@ class AmplifyClient:
         commitTime: datetime = None,
     ) -> StartJobResultTypeDef:
         """
-        [Client.start_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.start_job)
+        [Client.start_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.start_job)
         """
 
     def stop_job(self, appId: str, branchName: str, jobId: str) -> StopJobResultTypeDef:
         """
-        [Client.stop_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.stop_job)
+        [Client.stop_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.stop_job)
         """
 
     def tag_resource(self, resourceArn: str, tags: Dict[str, str]) -> Dict[str, Any]:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.tag_resource)
         """
 
     def untag_resource(self, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.untag_resource)
         """
 
     def update_app(
@@ -387,6 +387,7 @@ class AmplifyClient:
         basicAuthCredentials: str = None,
         customRules: List["CustomRuleTypeDef"] = None,
         buildSpec: str = None,
+        customHeaders: str = None,
         enableAutoBranchCreation: bool = None,
         autoBranchCreationPatterns: List[str] = None,
         autoBranchCreationConfig: "AutoBranchCreationConfigTypeDef" = None,
@@ -395,7 +396,7 @@ class AmplifyClient:
         accessToken: str = None,
     ) -> UpdateAppResultTypeDef:
         """
-        [Client.update_app documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.update_app)
+        [Client.update_app documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.update_app)
         """
 
     def update_branch(
@@ -419,7 +420,7 @@ class AmplifyClient:
         backendEnvironmentArn: str = None,
     ) -> UpdateBranchResultTypeDef:
         """
-        [Client.update_branch documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.update_branch)
+        [Client.update_branch documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.update_branch)
         """
 
     def update_domain_association(
@@ -432,26 +433,26 @@ class AmplifyClient:
         autoSubDomainIAMRole: str = None,
     ) -> UpdateDomainAssociationResultTypeDef:
         """
-        [Client.update_domain_association documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.update_domain_association)
+        [Client.update_domain_association documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.update_domain_association)
         """
 
     def update_webhook(
         self, webhookId: str, branchName: str = None, description: str = None
     ) -> UpdateWebhookResultTypeDef:
         """
-        [Client.update_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Client.update_webhook)
+        [Client.update_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Client.update_webhook)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_apps"]) -> ListAppsPaginator:
         """
-        [Paginator.ListApps documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Paginator.ListApps)
+        [Paginator.ListApps documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Paginator.ListApps)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_branches"]) -> ListBranchesPaginator:
         """
-        [Paginator.ListBranches documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Paginator.ListBranches)
+        [Paginator.ListBranches documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Paginator.ListBranches)
         """
 
     @overload
@@ -459,11 +460,11 @@ class AmplifyClient:
         self, operation_name: Literal["list_domain_associations"]
     ) -> ListDomainAssociationsPaginator:
         """
-        [Paginator.ListDomainAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Paginator.ListDomainAssociations)
+        [Paginator.ListDomainAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Paginator.ListDomainAssociations)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_jobs"]) -> ListJobsPaginator:
         """
-        [Paginator.ListJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.5/reference/services/amplify.html#Amplify.Paginator.ListJobs)
+        [Paginator.ListJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.48/reference/services/amplify.html#Amplify.Paginator.ListJobs)
         """
